| Title: | Interfacing 'NaileR' with 'Shiny' |
|---|---|
| Description: | A very small package for more convenient use of 'NaileR'. You provide a data set containing a latent variable you want to understand. It generates a description and an interpretation of this latent variable using a Large Language Model. For perceptual data, it describes the stimuli used in the experiment. |
| Authors: | Sébastien Lê [aut, cre] (ORCID: <https://orcid.org/0000-0001-8814-6714>) |
| Maintainer: | Sébastien Lê <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.1.1 |
| Built: | 2026-05-10 06:06:02 UTC |
| Source: | https://github.com/cran/PolisheR |
Shiny app principale
shiny_nail_catdes(dataset)shiny_nail_catdes(dataset)
dataset |
A data frame containing at least one categorical variable (factor). |
Launches a Shiny web application.
This function launches a Shiny app for interpreting a (latent) continuous variable with the 'Nailer' package.
shiny_nail_condes(dataset)shiny_nail_condes(dataset)
dataset |
A data frame containing the continuous variable to be analyzed. |
This function does not return a value; it launches a Shiny app.
if(interactive()){ # Processing time is often longer than ten seconds # because the function uses a large language model. library(FactoMineR) library(stringr) library(NaileR) data(beard_cont) res_ca_beard <- FactoMineR::CA(beard_cont, graph = FALSE) beard_work <- res_ca_beard$row$coord |> as.data.frame() beard_work <- beard_work[,1] |> cbind(beard_cont) intro_beard <- "These data refer to 8 types of beards. Each beard was evaluated by 62 assessors." intro_beard <- gsub('\n', ' ', intro_beard) |> stringr::str_squish() req_beard <- "Please explain what differentiates beards on both sides of the scale. Then, give the scale a name." req_beard <- gsub('\n', ' ', req_beard) |> stringr::str_squish() shiny_nail_condes(beard_work) }if(interactive()){ # Processing time is often longer than ten seconds # because the function uses a large language model. library(FactoMineR) library(stringr) library(NaileR) data(beard_cont) res_ca_beard <- FactoMineR::CA(beard_cont, graph = FALSE) beard_work <- res_ca_beard$row$coord |> as.data.frame() beard_work <- beard_work[,1] |> cbind(beard_cont) intro_beard <- "These data refer to 8 types of beards. Each beard was evaluated by 62 assessors." intro_beard <- gsub('\n', ' ', intro_beard) |> stringr::str_squish() req_beard <- "Please explain what differentiates beards on both sides of the scale. Then, give the scale a name." req_beard <- gsub('\n', ' ', req_beard) |> stringr::str_squish() shiny_nail_condes(beard_work) }
This function launches a Shiny app for analyzing QDA data with the 'Nailer' package. The app allows users to explore and analyze their QDA dataset.
shiny_nail_qda(dataset)shiny_nail_qda(dataset)
dataset |
A data frame containing the data to be analyzed. |
This function does not return a value; it launches a Shiny app.
if(interactive()){ # Processing time is often longer than ten seconds # because the function uses a large language model. library(SensoMineR) data(chocolates) shiny_nail_qda(sensochoc) }if(interactive()){ # Processing time is often longer than ten seconds # because the function uses a large language model. library(SensoMineR) data(chocolates) shiny_nail_qda(sensochoc) }